[![CircleCI](https://circleci.com/gh/nebiolabs/tasmanian/tree/master.svg?style=svg)](https://circleci.com/gh/nebiolabs/tasmanian/tree/master)
[![Bioconda](https://github.com/FredHutch/adpred-pkg/static/figures/bioconda-badge-wide.svg)
[![License](http://img.shields.io/badge/license-MIT-blue.svg)](https://github.com/nebiolabs/tasmanian/blob/master/LICENSE)
[![Language](https://img.shields.io/badge/Made%20with-Python-1f425f.svg)](https://www.python.org)  
  
# ADpred  

A tool for prediction of Transcription Activation Domains from protein sequences.

<!--toc start-->
 * [Goals](#goals)
 * [Documentation](https://adored.readthedocs.io/en/latest/)
 * [Contributing](#contributing)
 * [Authors](#authors)
 * [Licence](#licence)
<!--toc end -->


## Goals  

The main goal is to identify regions with high AD function probability in protein sequences. Moreover, at these observed regions, a saturated mutagenesis study can reveal insights into the important residues that confer the AD function to that region.

## Contributing

Contributions are welcome and encouraged.

## [Documentation](https://adored.readthedocs.io/en/latest/index.html?highlight=predict)

## Authors
* [Ariel Erijman](https://github.com/aerijman)

## Licence
`ADpred` is an open source software released under the [MIT licence](#)
